==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetIpTagArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains the IP tag associated with the public IP address.
 * @property ipTagType IP tag type. Example: FirstPartyUsage.
 * @property tag IP tag associated with the public IP. Example: SQL, Storage etc.
 */
public data class VirtualMachineScaleSetIpTagArgs(
    public val ipTagType: Output<String>? = null,
    public val tag: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs.builder()
            .ipTagType(ipTagType?.applyValue({ args0 -> args0 }))
            .tag(tag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetIpTagArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetIpTagArgsBuilder internal constructor() {
    private var ipTagType: Output<String>? = null

    private var tag: Output<String>? = null

    /**
     * @param value IP tag type. Example: FirstPartyUsage.
     */
    @JvmName("rvuiaedfbnghuwaj")
    public suspend fun ipTagType(`value`: Output<String>) {
        this.ipTagType = value
    }

    /**
     * @param value IP tag associated with the public IP. Example: SQL, Storage etc.
     */
    @JvmName("lofoaprbvpfwocag")
    public suspend fun tag(`value`: Output<String>) {
        this.tag = value
    }

    /**
     * @param value IP tag type. Example: FirstPartyUsage.
     */
    @JvmName("ugtousswflqidwap")
    public suspend fun ipTagType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipTagType = mapped
    }

    /**
     * @param value IP tag associated with the public IP. Example: SQL, Storage etc.
     */
    @JvmName("ahirqbdhcmstdjnk")
    public suspend fun tag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    internal fun build(): VirtualMachineScaleSetIpTagArgs = VirtualMachineScaleSetIpTagArgs(
        ipTagType = ipTagType,
        tag = tag,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetIpTagArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains the IP tag associated with the public IP address.
 * @property ipTagType IP tag type. Example: FirstPartyUsage.
 * @property tag IP tag associated with the public IP. Example: SQL, Storage etc.
 */
public data class VirtualMachineScaleSetIpTagArgs(
    public val ipTagType: Output<String>? = null,
    public val tag: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetIpTagArgs.builder()
            .ipTagType(ipTagType?.applyValue({ args0 -> args0 }))
            .tag(tag?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetIpTagArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetIpTagArgsBuilder internal constructor() {
    private var ipTagType: Output<String>? = null

    private var tag: Output<String>? = null

    /**
     * @param value IP tag type. Example: FirstPartyUsage.
     */
    @JvmName("wudgnsowhwcvjhtl")
    public suspend fun ipTagType(`value`: Output<String>) {
        this.ipTagType = value
    }

    /**
     * @param value IP tag associated with the public IP. Example: SQL, Storage etc.
     */
    @JvmName("pjblxcmqdvajjthm")
    public suspend fun tag(`value`: Output<String>) {
        this.tag = value
    }

    /**
     * @param value IP tag type. Example: FirstPartyUsage.
     */
    @JvmName("yvofawsmyjwbndpw")
    public suspend fun ipTagType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipTagType = mapped
    }

    /**
     * @param value IP tag associated with the public IP. Example: SQL, Storage etc.
     */
    @JvmName("tmjlwccodydisvsb")
    public suspend fun tag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tag = mapped
    }

    internal fun build(): VirtualMachineScaleSetIpTagArgs = VirtualMachineScaleSetIpTagArgs(
        ipTagType = ipTagType,
        tag = tag,
    )
}
